@@ -142,7 +142,11 @@ class SecureHomeKitProtocol(InsecureHomeKitProtocol):
             self.c2a_counter += 1
 
             data = chacha20_aead_encrypt(
-                len_bytes, self.c2a_key, cnt_bytes, bytes([0, 0, 0, 0]), current,
+                len_bytes,
+                self.c2a_key,
+                cnt_bytes,
+                bytes([0, 0, 0, 0]),
+                current,
             )
 
             buffer += len_bytes + data
@@ -219,8 +223,18 @@ class HomeKitConnection:
     def is_connected(self):
         return self.transport and self.protocol and not self.closed
 
-    def start_connector(self):
-        if self._connector:
+    def _start_connector(self):
+        """
+        Start a reconnect background task.
+
+        This function is *not* thread safe. It should only be called on the main thread
+        where the event loop is running. If it is not there is a race where multiple
+        reconnect tasks could run at once.
+
+        This function **will not** start another reconnect thread if one is already
+        running. Or if it is already connected.
+        """
+        if self._connector or self.is_connected:
             return
 
         def done_callback(result):
@@ -236,20 +250,33 @@ class HomeKitConnection:
         self._connector.add_done_callback(done_callback)
 
     async def ensure_connection(self):
+        """
+        Waits for a connection to the device.
+
+        If connected and authenticated returns immediately.
+
+        Otherwise, if a reconnection is in progress wait for it to complete.
+
+        Otherwise, start a reconnection and wait for it.
+        """
         if self.is_connected:
             return
         self.closing = False
-        self.start_connector()
+        self._start_connector()
         await asyncio.shield(self._connector)
 
-    async def stop_connector(self):
+    async def _stop_connector(self):
+        """
+        Cancels any active reconnect tasks.
+
+        If no active reconnect tasks it will return immediately.
+
+        Otherwise it will wait for the task to end.
+        """
         if not self._connector:
             return
         self._connector.cancel()
-        try:
-            await self._connector
-        except asyncio.CancelledError:
-            pass
+        await self._connector
         self._connector = None
 
     async def get(self, target):
@@ -257,7 +284,10 @@ class HomeKitConnection:
         Sends a HTTP POST request to the current transport and returns an awaitable
         that can be used to wait for a response.
         """
-        return await self.request(method="GET", target=target,)
+        return await self.request(
+            method="GET",
+            target=target,
+        )
 
     async def get_json(self, target):
         response = await self.get(target)
@@ -272,13 +302,15 @@ class HomeKitConnection:
         return await self.request(
             method="PUT",
             target=target,
-            headers=[("Content-Type", content_type), ("Content-Length", len(body))],
+            headers=[("Content-Length", len(body)), ("Content-Type", content_type)],
             body=body,
         )
 
     async def put_json(self, target, body):
         response = await self.put(
-            target, serialize_json(body), content_type=HttpContentTypes.JSON,
+            target,
+            serialize_json(body),
+            content_type=HttpContentTypes.JSON,
         )
 
         if response.code == 204:
@@ -310,13 +342,15 @@ class HomeKitConnection:
         return await self.request(
             method="POST",
             target=target,
-            headers=[("Content-Type", content_type), ("Content-Length", len(body))],
+            headers=[("Content-Length", len(body)), ("Content-Type", content_type)],
             body=body,
         )
 
     async def post_json(self, target, body):
         response = await self.post(
-            target, serialize_json(body), content_type=HttpContentTypes.JSON,
+            target,
+            serialize_json(body),
+            content_type=HttpContentTypes.JSON,
         )
 
         if response.code != 204:
@@ -342,7 +376,9 @@ class HomeKitConnection:
     async def post_tlv(self, target, body, expected=None):
         try:
             response = await self.post(
-                target, TLV.encode_list(body), content_type=HttpContentTypes.TLV,
+                target,
+                TLV.encode_list(body),
+                content_type=HttpContentTypes.TLV,
             )
         except HttpErrorResponse as e:
             self.transport.close()
@@ -415,7 +451,7 @@ class HomeKitConnection:
         """
         self.closing = True
 
-        await self.stop_connector()
+        await self._stop_connector()
 
         if self.transport:
             self.transport.close()
@@ -431,7 +467,7 @@ class HomeKitConnection:
         logger.debug("Connection %r lost.", self)
 
         if not self.closing:
-            self.start_connector()
+            self._start_connector()
 
         if self.closing:
             self.closed = True
@@ -477,7 +513,7 @@ class HomeKitConnection:
                 raise
 
             except asyncio.CancelledError:
-                raise
+                return
 
             except HomeKitException:
                 logger.debug(
@@ -516,7 +552,9 @@ class HomeKitConnection:
 class SecureHomeKitConnection(HomeKitConnection):
     def __init__(self, owner, pairing_data):
         super().__init__(
-            owner, pairing_data["AccessoryIP"], pairing_data["AccessoryPort"],
+            owner,
+            pairing_data["AccessoryIP"],
+            pairing_data["AccessoryPort"],
         )
         self.pairing_data = pairing_data
 
@@ -543,7 +581,9 @@ class SecureHomeKitConnection(HomeKitConnection):
         while True:
             try:
                 response = await self.post_tlv(
-                    "/pair-verify", body=request, expected=expected,
+                    "/pair-verify",
+                    body=request,
+                    expected=expected,
                 )
                 request, expected = state_machine.send(response)
             except StopIteration as result:
@@ -552,7 +592,11 @@ class SecureHomeKitConnection(HomeKitConnection):
                 break
 
         # Secure session has been negotiated - switch protocol so all future messages are encrypted
-        self.protocol = SecureHomeKitProtocol(self, a2c_key, c2a_key,)
+        self.protocol = SecureHomeKitProtocol(
+            self,
+            a2c_key,
+            c2a_key,
+        )
         self.transport.set_protocol(self.protocol)
         self.protocol.connection_made(self.transport)
 
