@@ -22,9 +22,11 @@ from aiohomekit.controller.pairing import AbstractPairing
 from aiohomekit.exceptions import (
     AccessoryDisconnectedError,
     AuthenticationError,
+    InvalidError,
     UnknownError,
     UnpairedError,
 )
+from aiohomekit.http import HttpContentTypes
 from aiohomekit.model.characteristics import CharacteristicsTypes
 from aiohomekit.model.services import ServicesTypes
 from aiohomekit.protocol import error_handler
@@ -85,26 +87,18 @@ class IpPairing(AbstractPairing):
         if self.subscriptions:
             await self.subscribe(self.subscriptions)
 
-    async def _ensure_connected(self, *, _timeout: float = 10):
+    async def _ensure_connected(self):
         try:
-            try:
-                await asyncio.wait_for(self.connection.ensure_connection(), _timeout)
-            except asyncio.TimeoutError:
-                raise AccessoryDisconnectedError(
-                    "Timeout while waiting for connection to device"
-                )
+            await asyncio.wait_for(self.connection.ensure_connection(), 10)
+        except asyncio.TimeoutError:
+            raise AccessoryDisconnectedError(
+                "Timeout while waiting for connection to device"
+            )
 
-            assert (
-                self.connection.is_connected
-            ), "must be connected or receive exception after waiting for connection attempt"
-        except:  # noqa: E722  # Re-raise with cleanup is unproblematic
-            # Ensure that no `_reconnect` task is left dangling in the background
-            #
-            # Previously, these would accumulate if the target device was
-            # temporarily unavailable and cause a SYN-storm to hit the device
-            # when it became available again.
-            await self.connection.close()
-            raise
+        if not self.connection.is_connected:
+            raise AccessoryDisconnectedError(
+                "Ensure connection returned but still not connected"
+            )
 
     async def close(self):
         """
@@ -406,13 +400,15 @@ class IpPairing(AbstractPairing):
             (TLV.kTLVType_Permissions, permissions),
         ]
 
-        data = await self.connection.post_tlv("/pairings", request_tlv)
+        data = dict(await self.connection.post_tlv("/pairings", request_tlv))
 
-        if len(data) == 1 and data[0][1] == TLV.M2:
-            return True
+        if data.get(TLV.kTLVType_State, TLV.M2) != TLV.M2:
+            raise InvalidError("Unexpected state after add pairing request")
 
-        # Map TLV error codes to an exception
-        error_handler(data[0][1], data[1][0])
+        if TLV.kTLVType_Error in data:
+            error_handler(data[TLV.kTLVType_Error], "M2")
+
+        return True
 
     async def remove_pairing(self, pairingId):
         """
@@ -436,29 +432,22 @@ class IpPairing(AbstractPairing):
             (TLV.kTLVType_Identifier, pairingId.encode("utf-8")),
         ]
 
-        data = await self.connection.post_tlv("/pairings", request_tlv)
+        data = dict(await self.connection.post_tlv("/pairings", request_tlv))
 
-        # act upon the response (the same is returned for IP and BLE accessories)
-        # handle the result, spec says, if it has only one entry with state == M2 we unpaired, else its an error.
-        logging.debug("response data: %s", data)
+        if data.get(TLV.kTLVType_State, TLV.M2) != TLV.M2:
+            raise InvalidError("Unexpected state after removing pairing request")
 
-        if len(data) == 1 and data[0][0] == TLV.kTLVType_State and data[0][1] == TLV.M2:
-            return True
+        if TLV.kTLVType_Error in data:
+            if data[TLV.kTLVType_Error] == TLV.kTLVError_Authentication:
+                raise AuthenticationError("Remove pairing failed: insufficient access")
+            raise UnknownError("Remove pairing failed: unknown error")
 
-        await self.connection.close()
-
-        if (
-            data[1][0] == TLV.kTLVType_Error
-            and data[1][1] == TLV.kTLVError_Authentication
-        ):
-            raise AuthenticationError("Remove pairing failed: missing authentication")
-
-        raise UnknownError("Remove pairing failed: unknown error")
+        return True
 
     async def image(self, accessory, width, height):
         resp = await self.connection.post(
             "/resource",
-            content_type="application/json",
+            content_type=HttpContentTypes.JSON,
             body=json.dumps(
                 {
                     "aid": accessory,
